@@ -16,7 +16,7 @@ class UserSerializer(serializers.ModelSerializer):
     class Meta:
         model = User
         fields = tuple(User.REQUIRED_FIELDS) + (
-            User._meta.pk.name,
+            settings.USER_ID_FIELD,
             settings.LOGIN_FIELD,
         )
         read_only_fields = (settings.LOGIN_FIELD,)
@@ -42,7 +42,7 @@ class UserCreateSerializer(serializers.ModelSerializer):
         model = User
         fields = tuple(User.REQUIRED_FIELDS) + (
             settings.LOGIN_FIELD,
-            User._meta.pk.name,
+            settings.USER_ID_FIELD,
             "password",
         )
 
@@ -114,7 +114,7 @@ class TokenCreateSerializer(serializers.Serializer):
     def validate(self, attrs):
         password = attrs.get("password")
         params = {settings.LOGIN_FIELD: attrs.get(settings.LOGIN_FIELD)}
-        self.user = authenticate(**params, password=password)
+        self.user = authenticate(request=self.context.get("request"), **params, password=password)
         if not self.user:
             self.user = User.objects.filter(**params).first()
             if self.user and not self.user.check_password(password):
@@ -136,8 +136,8 @@ class UserFunctionsMixin:
         except User.DoesNotExist:
             pass
         if (
-            settings.PASSWORD_RESET_SHOW_EMAIL_NOT_FOUND
-            or settings.USERNAME_RESET_SHOW_EMAIL_NOT_FOUND
+                settings.PASSWORD_RESET_SHOW_EMAIL_NOT_FOUND
+                or settings.USERNAME_RESET_SHOW_EMAIL_NOT_FOUND
         ):
             self.fail("email_not_found")
 
@@ -328,8 +328,10 @@ class UserDeleteSerializer(CurrentPasswordSerializer):
 
 
 class SetUsernameSerializer(UsernameSerializer, CurrentPasswordSerializer):
-    pass
+    class Meta:
+        model = User
+        fields = (settings.LOGIN_FIELD, 'current_password')
 
 
-class SetUsernameRetypeSerializer(UsernameRetypeSerializer, CurrentPasswordSerializer):
+class SetUsernameRetypeSerializer(SetUsernameSerializer, UsernameRetypeSerializer):
     pass
