@@ -1,5 +1,6 @@
-from django.contrib.auth import get_user_model
+from django.contrib.auth import get_user_model, update_session_auth_hash
 from django.contrib.auth.tokens import default_token_generator
+
 from django.utils.timezone import now
 from rest_framework import generics, status, views, viewsets
 from rest_framework.decorators import action
@@ -46,6 +47,7 @@ class UserViewSet(viewsets.ModelViewSet):
     queryset = User.objects.all()
     permission_classes = settings.PERMISSIONS.user
     token_generator = default_token_generator
+    lookup_field = settings.USER_ID_FIELD
 
     def permission_denied(self, request, message=None):
         if (
@@ -148,7 +150,7 @@ class UserViewSet(viewsets.ModelViewSet):
         super().perform_update(serializer)
         user = serializer.instance
         # should we send activation email after update?
-        if settings.SEND_ACTIVATION_EMAIL and not user.is_active:
+        if settings.SEND_ACTIVATION_EMAIL:
             context = {"user": user}
             to = [get_user_email(user)]
             settings.EMAIL.activation(self.request, context).send(to)
@@ -217,13 +219,15 @@ class UserViewSet(viewsets.ModelViewSet):
         self.request.user.set_password(serializer.data["new_password"])
         self.request.user.save()
 
-        if settings.LOGOUT_ON_PASSWORD_CHANGE:
-            utils.logout_user(self.request)
-
         if settings.PASSWORD_CHANGED_EMAIL_CONFIRMATION:
             context = {"user": self.request.user}
             to = [get_user_email(self.request.user)]
             settings.EMAIL.password_changed_confirmation(self.request, context).send(to)
+
+        if settings.LOGOUT_ON_PASSWORD_CHANGE:
+            utils.logout_user(self.request)
+        elif settings.CREATE_SESSION_ON_LOGIN:
+            update_session_auth_hash(self.request, self.request.user)
         return Response(status=status.HTTP_204_NO_CONTENT)
 
     @action(["post"], detail=False)
